"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class DlocalWalletOptionsTypedDict(TypedDict):
    name: NotRequired[Nullable[str]]
    r"""Passes `wallet.name` to the dLocal API for those connectors that need it."""
    email: NotRequired[Nullable[str]]
    r"""Passes `wallet.email` to the dLocal API for those connectors that need it."""
    token: NotRequired[Nullable[str]]
    r"""Passes `wallet.token` to the dLocal API for those connectors that need it."""
    username: NotRequired[Nullable[str]]
    r"""Passes `wallet.username` to the dLocal API for those connectors that need it."""
    verify: NotRequired[Nullable[bool]]
    r"""Passes `wallet.verify` to the dLocal API for those connectors that need it."""


class DlocalWalletOptions(BaseModel):
    name: OptionalNullable[str] = UNSET
    r"""Passes `wallet.name` to the dLocal API for those connectors that need it."""

    email: OptionalNullable[str] = UNSET
    r"""Passes `wallet.email` to the dLocal API for those connectors that need it."""

    token: OptionalNullable[str] = UNSET
    r"""Passes `wallet.token` to the dLocal API for those connectors that need it."""

    username: OptionalNullable[str] = UNSET
    r"""Passes `wallet.username` to the dLocal API for those connectors that need it."""

    verify: OptionalNullable[bool] = UNSET
    r"""Passes `wallet.verify` to the dLocal API for those connectors that need it."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["name", "email", "token", "username", "verify"]
        nullable_fields = ["name", "email", "token", "username", "verify"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
